/*
*  FormCheck currently supports the following input types:
*	- date (mm/dd/yyyyy)
*	- datemysql (yyyy-mm-dd)
*	- email
*	- ipaddress
*	- number
*	- text
*/
function securityCheck(input) 
{
	var badchars = Array('\'','\"','%','\\');
	for(var i=0; i<badchars.length;i++) {
		if(input.indexOf(badchars[i]) != -1)
		  return false;
	}
}

function inputCheck(input,type) 
{
	var errors = 0;
	var expression;
	
	if(type == 'int' || type == 'bigint' || type == 'number')
		expression	= /^-*\d+$/;
	else if(type == 'double' || type == 'float' || type == 'decimal')
		expression	= /(^-*\d+$)|(^-*\d+\.\d+$)/;
	else if(type == 'phone' || type == 'fax')
		expression	= /(^\++\d+$)|(^\d+$)/;
	else
		switch(type) {
			case 'email':
				expression	= /^.+\@(\[?)[a-zA-Z0-9\-\.]+\.([a-zA-Z]{2,3}|[0-9]{1,3})(\]?)$/;
			break;
			case 'date':
				expression	= /^\d{1,2}(\-|\/|\.)\d{1,2}\1\d{4}$/;
			break;
			case 'datedb':
				expression	= /^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})$/;
			break;
			case 'datemysql':
				expression	= /^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})$/;
			break;
			case 'ipaddress':
				expression	= /^((25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])$/;
			break;
			case 'smallint':
				expression	= /^[0,1]{1}$/;
			break;
			default:
				expression	= "";
			break;
		}

	if((errors == 0) && (expression != '')) 
		if(!expression.exec(input))//if(!expression.test(input))
		  errors++;

	if(errors==0) return true;
	else return false;
}

function formCheck(cform) 
{
	if(!cform) 
	{
		alert("Empty form object detected!");
		return false;
	}
	
	var confirm_element = false;
	var errors	= 0;
	var message	= "Please check the following input(s): \n";
	var controlmessages	= Array();
	var aux = false;
	
	var type,name,value,confirmed,checked,checkmessage,checkallownull,checktype,checkminlen,checkmaxlen,checkminvalue,checkmaxvalue,checkmandatorycheckbox,checkminwords,checkmaxwords;
	for(i = 0; i < cform.elements.length; i++) 
	{
		type = cform.elements[i].type;
		name = cform.elements[i].name;
		value = cform.elements[i].value;
		confirmed = cform.elements[i].getAttribute('confirmed');

		if(type == 'submit' && confirmed == 1) {
			confirm_element = cform.elements[i];
			break;
		}
		else
		{
			checked = cform.elements[i].getAttribute('checked');
			checkmessage = cform.elements[i].getAttribute('checkmessage');
			checkallownull = cform.elements[i].getAttribute('checkallownull');
			checktype = cform.elements[i].getAttribute('checktype');
			checkminlen = cform.elements[i].getAttribute('checkminlen');
			checkmaxlen = cform.elements[i].getAttribute('checkmaxlen');
			checkminvalue = cform.elements[i].getAttribute('checkminvalue');
			checkmaxvalue = cform.elements[i].getAttribute('checkmaxvalue');
			checkmandatorycheckbox = cform.elements[i].getAttribute('checkmandatorycheckbox');
			checkminwords = cform.elements[i].getAttribute('checkminwords');
			checkmaxwords = cform.elements[i].getAttribute('checkmaxwords');
			

			// Get manual message for this input
			if(checkmessage)
			  controlmessages[i] = checkmessage;
			else
			  controlmessages[i] = "";
			// Get message


			// 1. NULL CONTROL
			if(checkallownull && checkallownull=='false') {
				if(value) {
					if( (value == '' || value == ' ') || (type == "checkbox" && checked == false) )  {
						errors++;
						if(controlmessages[i] != "") 
					  	  message +="* "+controlmessages[i]+"\n";
						else
					 	  message +="* Field "+name+" cannot be blank.\n";	
					}
				}	 
				else {	
					errors++;
					if(controlmessages[i] != "") 
					  message +="* "+controlmessages[i]+"\n";
					else
					  message +="* Field "+name+" cannot be undefined.\n";
				}		
			}
			// END OF NULL CONTROL
		
			// 2. TYPE CONTROL
			if(checktype && value && !inputCheck(value,checktype)) {
				errors++;
				if(controlmessages[i] != "") 
				  message +="* "+controlmessages[i]+"\n";
				else
				  message +="* Invalid "+checktype+" format in "+name+".\n";
			}
			// END OF TYPE CONTROL


			// 3. LENGTH CONTROL
			if(checkminlen && value && value.length < checkminlen) {
				errors++;
				if(controlmessages[i] != "") 
				  message +="* "+controlmessages[i]+"\n";
				else
				  message +="* Length of "+name+" cannot be less than "+checkminlen+" characters.\n";
			}

			if(checkmaxlen && value && value.length > checkmaxlen) {
				errors++;
				if(controlmessages[i] != "") 
				  message +="* "+controlmessages[i]+"\n";
				else
				  message +="* Length of "+name+" cannot be more than "+checkmaxlen+" characters.\n";
			}
			// END OF LENGTH CONTROL
		

			// 4. MIN/MAX VALUE CONTROL FOR NUMBERS
			if(checkminvalue && value && value < checkminvalue) {
				errors++;
				if(controlmessages[i] != "") 
				  message +="* "+controlmessages[i]+"\n";
				else
				  message +="* Value of "+name+" cannot be less than "+checkminvalue+".\n";
			}

			if(checkmaxvalue && value && value > checkmaxvalue) {
				errors++;
				if(controlmessages[i] != "") 
				  message +="* "+controlmessages[i]+"\n";
				else
				  message +="* Value of "+name+" cannot be less than "+checkmaxvalue+".\n";
			}
			// END OF MIN/MAX VALUE CONTROL


			// 5. CHECK MANDATORY CHECKBOX
			if(checkmandatorycheckbox && !checked) {
				if(controlmessages[i] != "") 
				  message +="* "+controlmessages[i]+"\n";
				else
				  message +="* Value of "+name+" cannot be less than "+checkminvalue+".\n";
			}
			// END CHECK MANDATORY CHECKBOX
			

			// 6. MIN NUMBER OF WORDS
			if(checkminwords && checkminwords >= 0 && value) {
				aux = strCountValue(value);
				if(aux < checkminwords) {
					errors++;
					if(controlmessages[i] != "") 
					  message +="* "+controlmessages[i]+"\n";
					else
					  message +="* Value of "+name+" need to have more than "+checkminwords+" word(s).\n";
				}
			}
			// END MIN NUMBER OF WORDS


			// 7. MAX NUMBER OF WORDS
			if(checkmaxwords && checkmaxwords >= 0 && value) {
				aux = strCountValue(value);
				if(aux > checkmaxwords) {
					errors++;
					if(controlmessages[i] != "") 
					  message +="* "+controlmessages[i]+"\n";
					else
					  message +="* Value of "+name+" need to have less than "+checkmaxwords+" word(s).\n";
				}
			}
			// END MAX NUMBER OF WORDS

		}
	} // END OF THE FOR LOOP

	if(errors == 0) {
		if(confirm_element && confirm_element.confirmed == 1) {
			confirm_element.confirmed = false;
			if(confirm('Do you want continue?') == true)
				return true;
			else return false;
		}
		else return true;
	}else {
	  alert(message);
	  return false;	
	}	
	return false;
}

function strCountValue(value)
{
	var value_splited = value.split(" ");
	var counter = 0;
	for(j = 0; j < value_splited.length; j++)
		if(value_splited[j])
			++counter;
	return counter;
}
